package prefuse.activity;

import prefuse.util.collections.CopyOnWriteArrayList;

public abstract class Activity
{
  public static final long INFINITY = -1L;
  public static final long DEFAULT_STEP_TIME = 15L;
  private boolean m_enabled = true;
  private Pacer m_pacer;
  private long m_startTime = -1L;
  private long m_duration = -1L;
  private long m_stepTime = -1L;
  private long m_nextTime = -1L;
  private boolean m_isRunning = false;
  private boolean m_isScheduled = false;
  private CopyOnWriteArrayList m_listeners;
  
  public Activity(long paramLong)
  {
    this(paramLong, 15L);
  }
  
  public Activity(long paramLong1, long paramLong2)
  {
    this(paramLong1, paramLong2, System.currentTimeMillis());
  }
  
  public Activity(long paramLong1, long paramLong2, long paramLong3)
  {
    this.m_startTime = paramLong3;
    this.m_nextTime = paramLong3;
    this.m_duration = paramLong1;
    this.m_stepTime = paramLong2;
  }
  
  public void run()
  {
    ActivityManager.scheduleNow(this);
  }
  
  public void runAt(long paramLong)
  {
    ActivityManager.scheduleAt(this, paramLong);
  }
  
  public void runAfter(Activity paramActivity)
  {
    ActivityManager.scheduleAfter(paramActivity, this);
  }
  
  public void alwaysRunAfter(Activity paramActivity)
  {
    ActivityManager.alwaysScheduleAfter(paramActivity, this);
  }
  
  protected abstract void run(long paramLong);
  
  long runActivity(long paramLong)
  {
    if (paramLong < this.m_startTime) {
      return this.m_startTime - paramLong;
    }
    long l = paramLong - this.m_startTime;
    if ((this.m_duration == 0L) || (paramLong >= getStopTime()))
    {
      if (!setRunning(true)) {
        fireActivityStarted();
      }
      if (this.m_enabled)
      {
        run(l);
        fireActivityStepped();
      }
      setRunning(false);
      fireActivityFinished();
      return -1L;
    }
    if (paramLong >= this.m_nextTime)
    {
      if (!setRunning(true)) {
        fireActivityStarted();
      }
      if (this.m_enabled)
      {
        run(l);
        fireActivityStepped();
      }
      this.m_nextTime = (paramLong + this.m_stepTime);
    }
    return this.m_nextTime - paramLong;
  }
  
  public void cancel()
  {
    int i = 0;
    synchronized (this)
    {
      if (isScheduled())
      {
        ActivityManager.removeActivity(this);
        i = 1;
      }
      setRunning(false);
    }
    if (i != 0) {
      fireActivityCancelled();
    }
  }
  
  public synchronized boolean isScheduled()
  {
    return this.m_isScheduled;
  }
  
  void setScheduled(boolean paramBoolean)
  {
    int i;
    synchronized (this)
    {
      i = (paramBoolean) && (!this.m_isScheduled) ? 1 : 0;
      this.m_isScheduled = paramBoolean;
    }
    if (i != 0) {
      fireActivityScheduled();
    }
  }
  
  synchronized boolean setRunning(boolean paramBoolean)
  {
    boolean bool = this.m_isRunning;
    this.m_isRunning = paramBoolean;
    return bool;
  }
  
  public synchronized boolean isRunning()
  {
    return this.m_isRunning;
  }
  
  public void addActivityListener(ActivityListener paramActivityListener)
  {
    if (this.m_listeners == null) {
      this.m_listeners = new CopyOnWriteArrayList();
    }
    if (!this.m_listeners.contains(paramActivityListener)) {
      this.m_listeners.add(paramActivityListener);
    }
  }
  
  public void removeActivityListener(ActivityListener paramActivityListener)
  {
    if (this.m_listeners == null) {
      return;
    }
    this.m_listeners.remove(paramActivityListener);
    if (this.m_listeners.size() == 0) {
      this.m_listeners = null;
    }
  }
  
  protected void fireActivityScheduled()
  {
    if (this.m_listeners == null) {
      return;
    }
    Object[] arrayOfObject = this.m_listeners.getArray();
    for (int i = 0; i < arrayOfObject.length; i++) {
      ((ActivityListener)arrayOfObject[i]).activityScheduled(this);
    }
  }
  
  protected void fireActivityStarted()
  {
    if (this.m_listeners == null) {
      return;
    }
    Object[] arrayOfObject = this.m_listeners.getArray();
    for (int i = 0; i < arrayOfObject.length; i++) {
      ((ActivityListener)arrayOfObject[i]).activityStarted(this);
    }
  }
  
  protected void fireActivityStepped()
  {
    if (this.m_listeners == null) {
      return;
    }
    Object[] arrayOfObject = this.m_listeners.getArray();
    for (int i = 0; i < arrayOfObject.length; i++) {
      ((ActivityListener)arrayOfObject[i]).activityStepped(this);
    }
  }
  
  protected void fireActivityFinished()
  {
    if (this.m_listeners == null) {
      return;
    }
    Object[] arrayOfObject = this.m_listeners.getArray();
    for (int i = 0; i < arrayOfObject.length; i++) {
      ((ActivityListener)arrayOfObject[i]).activityFinished(this);
    }
  }
  
  protected void fireActivityCancelled()
  {
    if (this.m_listeners == null) {
      return;
    }
    Object[] arrayOfObject = this.m_listeners.getArray();
    for (int i = 0; i < arrayOfObject.length; i++) {
      ((ActivityListener)arrayOfObject[i]).activityCancelled(this);
    }
  }
  
  public double getPace(long paramLong)
  {
    long l = getDuration();
    double d = l == 0L ? 0.0D : paramLong / l;
    d = Math.min(1.0D, Math.max(0.0D, d));
    return this.m_pacer != null ? this.m_pacer.pace(d) : d;
  }
  
  public synchronized Pacer getPacingFunction()
  {
    return this.m_pacer;
  }
  
  public synchronized void setPacingFunction(Pacer paramPacer)
  {
    this.m_pacer = paramPacer;
  }
  
  public long getStopTime()
  {
    if (this.m_duration == -1L) {
      return Long.MAX_VALUE;
    }
    return this.m_startTime + this.m_duration;
  }
  
  public long getNextTime()
  {
    return this.m_nextTime;
  }
  
  public long getDuration()
  {
    return this.m_duration;
  }
  
  public void setDuration(long paramLong)
  {
    this.m_duration = paramLong;
  }
  
  public long getStartTime()
  {
    return this.m_startTime;
  }
  
  public void setStartTime(long paramLong)
  {
    this.m_startTime = paramLong;
  }
  
  public long getStepTime()
  {
    return this.m_stepTime;
  }
  
  public void setStepTime(long paramLong)
  {
    this.m_stepTime = paramLong;
  }
  
  public boolean isEnabled()
  {
    return this.m_enabled;
  }
  
  public void setEnabled(boolean paramBoolean)
  {
    this.m_enabled = paramBoolean;
  }
}


/* Location:              C:\Perforce\MyAsup\dev\thirdparty\lib\asup-metamodel-client-1.0.jar!\prefuse\activity\Activity.class
 * Java compiler version: 5 (49.0)
 * JD-Core Version:       0.7.1
 */